==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/hybridcloud/kotlin/CloudConnector.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcloud.kotlin

import com.pulumi.azurenative.hybridcloud.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.hybridcloud.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [CloudConnector].
 */
@PulumiTagMarker
public class CloudConnectorResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: CloudConnectorArgs = CloudConnectorArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend CloudConnectorArgsBuilder.() -> Unit) {
        val builder = CloudConnectorArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): CloudConnector {
        val builtJavaResource =
            com.pulumi.azurenative.hybridcloud.CloudConnector(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return CloudConnector(builtJavaResource)
    }
}

/**
 * Cloud Connector resource.
 * Azure REST API version: 2023-01-01-preview. Prior API version in Azure Native 1.x: 2023-01-01-preview.
 * ## Example Usage
 * ### Create a Cloud Connector
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var cloudConnector = new AzureNative.HybridCloud.CloudConnector("cloudConnector", new()
 *     {
 *         AccountId = "123456789012",
 *         CloudConnectorName = "123456789012",
 *         CloudType = "AWS",
 *         Location = "West US",
 *         ResourceGroupName = "demo-rg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/hybridcloud/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := hybridcloud.NewCloudConnector(ctx, "cloudConnector", &hybridcloud.CloudConnectorArgs{
 * 			AccountId:          pulumi.String("123456789012"),
 * 			CloudConnectorName: pulumi.String("123456789012"),
 * 			CloudType:          pulumi.String("AWS"),
 * 			Location:           pulumi.String("West US"),
 * 			ResourceGroupName:  pulumi.String("demo-rg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.hybridcloud.CloudConnector;
 * import com.pulumi.azurenative.hybridcloud.CloudConnectorArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var cloudConnector = new CloudConnector("cloudConnector", CloudConnectorArgs.builder()
 *             .accountId("123456789012")
 *             .cloudConnectorName("123456789012")
 *             .cloudType("AWS")
 *             .location("West US")
 *             .resourceGroupName("demo-rg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:hybridcloud:CloudConnector 123456789012 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.HybridCloud/cloudConnectors/{cloudConnectorName}
 * ```
 */
public class CloudConnector internal constructor(
    override val javaResource: com.pulumi.azurenative.hybridcloud.CloudConnector,
) : KotlinCustomResource(javaResource, CloudConnectorMapper) {
    /**
     * Account identifier of the remote cloud.
     */
    public val accountId: Output<String>?
        get() = javaResource.accountId().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The cloud connector type.
     */
    public val cloudType: Output<String>?
        get() = javaResource.cloudType().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * A unique read-only string that changes whenever the resource is updated.
     */
    public val etag: Output<String>
        get() = javaResource.etag().applyValue({ args0 -> args0 })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The provisioning state of the cloud connector resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object CloudConnectorMapper : ResourceMapper<CloudConnector> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.hybridcloud.CloudConnector::class == javaResource::class

    override fun map(javaResource: Resource): CloudConnector = CloudConnector(
        javaResource as
            com.pulumi.azurenative.hybridcloud.CloudConnector,
    )
}

/**
 * @see [CloudConnector].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [CloudConnector].
 */
public suspend fun cloudConnector(
    name: String,
    block: suspend CloudConnectorResourceBuilder.() -> Unit,
): CloudConnector {
    val builder = CloudConnectorResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [CloudConnector].
 * @param name The _unique_ name of the resulting resource.
 */
public fun cloudConnector(name: String): CloudConnector {
    val builder = CloudConnectorResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/hybridcloud/kotlin/CloudConnector.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcloud.kotlin

import com.pulumi.azurenative.hybridcloud.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.hybridcloud.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map

/**
 * Builder for [CloudConnector].
 */
@PulumiTagMarker
public class CloudConnectorResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: CloudConnectorArgs = CloudConnectorArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend CloudConnectorArgsBuilder.() -> Unit) {
        val builder = CloudConnectorArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): CloudConnector {
        val builtJavaResource =
            com.pulumi.azurenative.hybridcloud.CloudConnector(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return CloudConnector(builtJavaResource)
    }
}

/**
 * Cloud Connector resource.
 * Azure REST API version: 2023-01-01-preview. Prior API version in Azure Native 1.x: 2023-01-01-preview.
 * ## Example Usage
 * ### Create a Cloud Connector
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var cloudConnector = new AzureNative.HybridCloud.CloudConnector("cloudConnector", new()
 *     {
 *         AccountId = "123456789012",
 *         CloudConnectorName = "123456789012",
 *         CloudType = AzureNative.HybridCloud.CloudType.AWS,
 *         Location = "West US",
 *         ResourceGroupName = "demo-rg",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/hybridcloud/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := hybridcloud.NewCloudConnector(ctx, "cloudConnector", &hybridcloud.CloudConnectorArgs{
 * 			AccountId:          pulumi.String("123456789012"),
 * 			CloudConnectorName: pulumi.String("123456789012"),
 * 			CloudType:          pulumi.String(hybridcloud.CloudTypeAWS),
 * 			Location:           pulumi.String("West US"),
 * 			ResourceGroupName:  pulumi.String("demo-rg"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.hybridcloud.CloudConnector;
 * import com.pulumi.azurenative.hybridcloud.CloudConnectorArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var cloudConnector = new CloudConnector("cloudConnector", CloudConnectorArgs.builder()
 *             .accountId("123456789012")
 *             .cloudConnectorName("123456789012")
 *             .cloudType("AWS")
 *             .location("West US")
 *             .resourceGroupName("demo-rg")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:hybridcloud:CloudConnector 123456789012 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.HybridCloud/cloudConnectors/{cloudConnectorName}
 * ```
 */
public class CloudConnector internal constructor(
    override val javaResource: com.pulumi.azurenative.hybridcloud.CloudConnector,
) : KotlinCustomResource(javaResource, CloudConnectorMapper) {
    /**
     * Account identifier of the remote cloud.
     */
    public val accountId: Output<String>?
        get() = javaResource.accountId().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * The cloud connector type.
     */
    public val cloudType: Output<String>?
        get() = javaResource.cloudType().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * A unique read-only string that changes whenever the resource is updated.
     */
    public val etag: Output<String>
        get() = javaResource.etag().applyValue({ args0 -> args0 })

    /**
     * The geo-location where the resource lives
     */
    public val location: Output<String>
        get() = javaResource.location().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The provisioning state of the cloud connector resource.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * Resource tags.
     */
    public val tags: Output<Map<String, String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object CloudConnectorMapper : ResourceMapper<CloudConnector> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.hybridcloud.CloudConnector::class == javaResource::class

    override fun map(javaResource: Resource): CloudConnector = CloudConnector(
        javaResource as
            com.pulumi.azurenative.hybridcloud.CloudConnector,
    )
}

/**
 * @see [CloudConnector].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [CloudConnector].
 */
public suspend fun cloudConnector(
    name: String,
    block: suspend CloudConnectorResourceBuilder.() -> Unit,
): CloudConnector {
    val builder = CloudConnectorResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [CloudConnector].
 * @param name The _unique_ name of the resulting resource.
 */
public fun cloudConnector(name: String): CloudConnector {
    val builder = CloudConnectorResourceBuilder()
    builder.name(name)
    return builder.build()
}
